#! /usr/bin/python
# -*- coding: utf-8 -*-

import gi
gi.require_version('Gtk', '3.0')
from gi.repository import Gtk, Gio
import signal
import subprocess
import shlex
import os
import shutil

class GEDUConfig(Gtk.Window):

    def execute(self, command):
        args = shlex.split(command)
        p = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False)
        out, err = p.communicate()
        return out, err

    def AutologinStatus(self):
        # Commands to execute for MD5 checksums
        withautologin = "md5sum /usr/share/cga/cga-lightdm-config/lightdm-autologin.conf"
        withoutautologin = "md5sum /usr/share/cga/cga-lightdm-config/lightdm.conf"
        status = "md5sum /etc/lightdm/lightdm.conf"

        # Execution of the command
        md5with, _ = self.execute(withautologin)
        md5without, _ = self.execute(withoutautologin)
        md5config, _ = self.execute(status)

        # Strip only MD5 checksums
        md5with = ''.join(md5with).split(' ')[0]
        md5without = ''.join(md5without).split(' ')[0]
        md5config = ''.join(md5config).split(' ')[0]

        if md5config == md5with:
            return True
        elif md5config == md5without:
            return False
        else:
            return False

    def on_autologin_switch_changed(self, switch, gparam):
        # Autologin is active in lightdm.conf:
        if self.AutologinStatus() == True:
            # Deactivating autologin
            self.execute("sudo /usr/share/guadalinexedu-configurator/setautologin deactivate")
        # Autologin isn't active in lightdm.conf:
        else:
            # Activating autologin
            self.execute("sudo /usr/share/guadalinexedu-configurator/setautologin activate")


    def button_dd_clicked_cb(self, widget, data = None):
	dialog = Gtk.MessageDialog(self, 0, Gtk.MessageType.WARNING, Gtk.ButtonsType.OK_CANCEL, "Restauración del escritorio Guadalinex Edu")
	dialog.format_secondary_text("El proceso de restauración borrará cualquier configuración realizada sobre el escritorio, como por ejemplo el cambio de fondo de escritorio o el tema de colores. Despues de la restauración la aplicación le solicitará reiniciar la sesión de usuario para aplicar los cambios. Si desea continuar pulse el botón Aceptar.")
	response = dialog.run()
	if response == Gtk.ResponseType.OK:
		self.restore_default_desktop()

	dialog.destroy()


    def restore_default_desktop(self):
	pathskel = '/etc/skel'
	homedir = os.getenv("HOME")
	pathfiles_skel = os.listdir(pathskel)
	for entry in pathfiles_skel:
		if os.path.isdir('%s/%s' % (pathskel, entry)):
			if os.path.isdir('%s/%s' % (homedir, entry)):
				shutil.rmtree('%s/%s' % (homedir, entry))
			shutil.copytree('%s/%s' % (pathskel, entry), '%s/%s' % (homedir, entry))
		elif os.path.isfile('%s/%s' % (pathskel, entry)):
			if os.path.isfile('%s/%s' % (homedir, entry)):
				os.remove('%s/%s' % (homedir, entry))
			shutil.copy('%s/%s' % (pathskel, entry), homedir)
	try:
		lxsessionpid = os.environ['_LXSESSION_PID']
		self.execute("kill -TERM %s" % lxsessionpid)
	except KeyError:
		self.execute('gnome-session-quit')

    def __init__(self):
        """ Class init event """
        # Setup the window with title and border width.
        Gtk.Window.__init__(self, type=Gtk.WindowType.TOPLEVEL,
                                  title="Configurador de Escritorio de Guadalinex Edu",
                                  resizable=False,
                                  border_width=10)

        # Create a Vertical child box.
        vbox = Gtk.Box.new(Gtk.Orientation.VERTICAL, 6)

        # Create and bind the Gtk Switch with the gsettings schema and its key.
        # volumes-visible path in nautilus.desktop schema
        # ----------------------------------------------------------------------- No volumes veisible switch in Xenial version
        # ----------------------------------------------------------------------- G9Slim: The schema org.gnome.nautilus.gschema.xml
        #                                                                                 isn't installed in slim version. As workaround,
        #                                                                                 put nautilus-data as dependency.
        # nautilus_desktop_switch = Gtk.Switch()
        # nautilus_desktop_setting = Gio.Settings.new("org.gnome.nautilus.desktop")
        # nautilus_desktop_setting.bind("volumes-visible", nautilus_desktop_switch, "active", Gio.SettingsBindFlags.DEFAULT)

        # Create the label for the volumes visible switch
        volumes_visible_label = Gtk.Label("Mostrar en el escritorio los volúmenes montados")

        # Create the autologin switch
        autologin_switch = Gtk.Switch()
        autologin_switch.set_active(self.AutologinStatus())
        autologin_switch.connect("notify::active", self.on_autologin_switch_changed)

        # Create the label for the autologin switch
        autologin_label = Gtk.Label("Login automático para el usuario \"usuario\"")

        # Position the Switch and its Label inside a Horizontal child box.
        # ----------------------------------------------------------------------- No volumes veisible switch in Xenial version
        # box = Gtk.Box.new(Gtk.Orientation.HORIZONTAL, 40)
        # box.pack_start(volumes_visible_label, False, False, 10)
        # box.pack_end(nautilus_desktop_switch, False, False, 10)
        # vbox.pack_start(box, False, False, 0)

        box = Gtk.Box.new(Gtk.Orientation.HORIZONTAL, 40)
        box.pack_start(autologin_label, False, False, 10)
        box.pack_end(autologin_switch, False, False, 10)
        vbox.pack_start(box, False, False, 1)

	# Bloque para incluir el restaurador de escritorio
        box_dd = Gtk.Box.new(Gtk.Orientation.HORIZONTAL, 40)
	label_dd = Gtk.Label("Restaurar el escritorio por defecto de Guadalinex Edu")
	button_dd = Gtk.Button("Ejecutar")
	button_dd.connect("clicked", self.button_dd_clicked_cb)
	box_dd.pack_start(label_dd, False, False, 10)
	box_dd.pack_start(button_dd, False, False, 10)
	vbox.pack_start(box_dd, False, False, 1)

        # Add the child box to the window
        self.add(vbox)
        self.connect("destroy", Gtk.main_quit)
        signal.signal(signal.SIGINT, signal.SIG_DFL)

if __name__ == "__main__":
    window = GEDUConfig()
    window.set_position(Gtk.WindowPosition.CENTER)
    window.show_all()
    Gtk.main()
